import pika


def open_connection(broker, vhost, user, password, queue_name, durable):
    try:
        connection = pika.BlockingConnection(pika.ConnectionParameters(
            host=broker,
            virtual_host=vhost,
            credentials=pika.PlainCredentials(user, password)
        ))
    except pika.exceptions.AMQPConnectionError as e:
        print("connection failure for %s: %s" % (broker, e))
        return None, None
    channel = connection.channel()
    channel.queue_declare(queue_name, durable=durable)

    return connection, channel



import argparse


def parse_command_line():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "BROKER",
        help="The IP address or hostname of the broker, default = %(default)s",
        default="localhost",
        nargs="+")
    parser.add_argument(
        "--durable",
        action="store_true")
    parser.add_argument(
        "--queue",
        help="The queue to use, default = %(default)s",
        type=str,
        default="test_queue")
    parser.add_argument(
        "--send",
        metavar="MSG",
        help="Send MSG to queue")
    parser.add_argument(
        "--get",
        help="Get one message from queue",
        action="store_true")
    parser.add_argument(
        "--list",
        help="List messages in queue",
        action="store_true")
    parser.add_argument(
        "--user",
        help="The user to use for the RabbitMQ connection, "
        "default = %(default)s",
        default="tester")
    parser.add_argument(
        "--password",
        help="The password to use for the RabbitMQ connection, "
        "default = %(default)s",
        default="linux")
    parser.add_argument(
        "--vhost",
        help="The vhost to use for the RabbitMQ connection, "
        "default = %(default)s",
        default="tester")
    parser.add_argument(
        "--delete",
        metavar="QUEUE",
        help="Delete QUEUE")
    return parser.parse_args()



import setuptools
import subprocess
from os import path


def long_description():
    this_directory = path.abspath(path.dirname(__file__))
    try:
        with open(path.join(this_directory, 'README.md'),
                  encoding='utf-8') as f:
            return f.read()
    except TypeError:
        with open(path.join(this_directory, 'README.md')) as f:
            return f.read()


def get_version():
    try:
        git = subprocess.run(['git', 'describe', '--tags'],
                             stdout=subprocess.PIPE, universal_newlines=True)
        full_version = git.stdout.strip()[1:]
    except AttributeError:
        git = subprocess.Popen(['git', 'describe', '--tags'],
                               stdout=subprocess.PIPE, universal_newlines=True)
        stdout_raw, stderr_raw = git.communicate()
        git.wait()
        full_version = stdout_raw.strip()[1:]
    except Exception:
        print("Cannot read version")
        raise

    try:
        git = subprocess.run(['git', 'describe', '--tags', '--abbrev=0'],
                             stdout=subprocess.PIPE, universal_newlines=True)
        abbreviated_version = git.stdout.strip()[1:]
    except AttributeError:
        git = subprocess.Popen(['git', 'describe', '--tags', '--abbrev=0'],
                               stdout=subprocess.PIPE, universal_newlines=True)
        stdout_raw, stderr_raw = git.communicate()
        git.wait()
        abbreviated_version = stdout_raw.strip()[1:]
    except Exception:
        print("Cannot read version")
        raise

    local_version = full_version.replace(abbreviated_version, '')

    if len(local_version) > 0:
        version = (abbreviated_version + '+'
                   + local_version[1:].replace('-', '.'))
    else:
        version = abbreviated_version

    return version


setuptools.setup(
    name="RabbitMQ Test Tool",
    version=get_version(),
    description="A simple test script to test a RabbitMQ cluster",
    long_description=long_description(),
    long_description_content_type="text/markdown",
    author="Nicolas Bock",
    packages=['rabbitmqtesttool'],
    entry_points={
        "console_scripts": [
            "rabbitmq-test-tool = rabbitmqtesttool.main:main",
        ],
    }
)
